import { QueryTableSource } from '@yukawa/chain-base-angular-store';
import { BehaviorSubject } from 'rxjs';
import { EventEmitter, isDevMode, Component, ViewEncapsulation, Input, Output, ViewChild, NgModule, CUSTOM_ELEMENTS_SCHEMA } from '@angular/core';
import '@angular/cdk/table';
import { MatSort, MatSortModule } from '@angular/material/sort';
import { MatTableModule } from '@angular/material/table';
import { MatSlideToggleModule } from '@angular/material/slide-toggle';
import { MatIconModule } from '@angular/material/icon';
import { MatButtonModule } from '@angular/material/button';
import { MatRippleModule } from '@angular/material/core';
import { FlexLayoutModule } from '@angular/flex-layout';
import { CommonModule } from '@angular/common';
import { MatTooltipModule } from '@angular/material/tooltip';
import { MatMenuModule, MatCheckboxModule } from '@angular/material';

/**
 * @fileoverview added by tsickle
 * Generated from: file/file-table/file-info-query.store.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class FileInfoQueryStore extends QueryTableSource {
    /**
     * @param {?} service
     * @param {?=} paginator
     * @param {?=} sort
     * @param {?=} tableFilter
     */
    constructor(service, paginator, sort, tableFilter) {
        super(paginator, sort, tableFilter);
        this.service = service;
        this.paginator = paginator;
        this.sort = sort;
        this.tableFilter = tableFilter;
        this.filterSubject = new BehaviorSubject(tableFilter);
    }
    /**
     * @protected
     * @return {?}
     */
    queryTable() {
        /** @type {?} */
        let filter = this.findFilter();
        this.applyFilter(filter);
        if (filter.keyword)
            filter.keyword += '*';
        return this.service.queryFiles(filter);
    }
}
if (false) {
    /**
     * @type {?}
     * @protected
     */
    FileInfoQueryStore.prototype.service;
    /**
     * @type {?}
     * @protected
     */
    FileInfoQueryStore.prototype.paginator;
    /**
     * @type {?}
     * @protected
     */
    FileInfoQueryStore.prototype.sort;
    /**
     * @type {?}
     * @protected
     */
    FileInfoQueryStore.prototype.tableFilter;
}

/**
 * @fileoverview added by tsickle
 * Generated from: file/file-table/file-table.component.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
//import {TableFilter} from "../../../../../../../../../libs/chain-base/front/angular/domain/target/angular";
/** @type {?} */
const TAG = 'FileTableComponent';
class FileTableComponent {
    constructor() {
        this.displayedColumns = ['icon', 'fileName', 'size', 'modified', 'detail-button'];
        //@Output()
        //rowSelected = new EventEmitter<FileInfo|any>();
        this.action = new EventEmitter();
    }
    /**
     * @return {?}
     */
    ngOnInit() {
    }
    /**
     * On destroy
     * @return {?}
     */
    ngOnDestroy() {
        // Unsubscribe from all subscriptions
        // this.rowSelected.next();
        this.action.complete();
    }
    /**
     * @param {?} event
     * @param {?} cmd
     * @param {?} selected
     * @return {?}
     */
    onAction(event, cmd, selected) {
        if (isDevMode()) {
            console.debug(TAG, "onAction", cmd, selected);
        }
        event.stopPropagation();
        this.fireAction((/** @type {?} */ ({ name: cmd, payload: selected })));
    }
    /**
     * @protected
     * @param {?} action
     * @return {?}
     */
    fireAction(action) {
        this.action.emit(action);
    }
}
FileTableComponent.decorators = [
    { type: Component, args: [{
                selector: 'chain-docs-file-table',
                template: "<mat-table #table [dataSource]=\"dataSource\" matSort matSortActive=\"fileName\"\n matSortDirection=\"asc\">    <!--[@animateStagger]=\"{value:'50'}\"-->\n\n    <!-- Type Column -->\n    <ng-container matColumnDef=\"icon\">\n        <mat-header-cell *matHeaderCellDef fxFlex=\"64px\"></mat-header-cell>\n        <mat-cell *matCellDef=\"let row\" fxFlex=\"64px\">\n            <mat-icon class=\"type-icon\" [ngClass]=\"row.type\"></mat-icon>\n        </mat-cell>\n    </ng-container>\n\n    <!-- Name Column -->\n    <ng-container matColumnDef=\"fileName\">\n        <mat-header-cell mat-sort-header *matHeaderCellDef>Name</mat-header-cell>\n        <mat-cell *matCellDef=\"let row\"> {{row.fileName}}</mat-cell>\n    </ng-container>\n\n    <!-- Type Column -->\n    <!-- <ng-container matColumnDef=\"type\">\n        <mat-header-cell mat-sort-header *matHeaderCellDef fxHide fxShow.gt-md>Type</mat-header-cell>\n        <mat-cell *matCellDef=\"let row\" fxHide fxShow.gt-md> {{row.type}}</mat-cell>\n    </ng-container> -->\n\n    <!-- Owner Column -->\n    <!-- <ng-container matColumnDef=\"owner\">\n        <mat-header-cell mat-sort-header *matHeaderCellDef fxHide.xs>Owner</mat-header-cell>\n        <mat-cell *matCellDef=\"let row\" fxHide.xs> {{row.created?.user}}</mat-cell>\n    </ng-container> -->\n\n    <!-- Size Column -->\n    <ng-container matColumnDef=\"size\">\n        <mat-header-cell mat-sort-header *matHeaderCellDef fxHide.xs>Size</mat-header-cell>\n        <mat-cell *matCellDef=\"let row\" fxHide.xs>{{row?.fileSize  == undefined ? '-': row.fileSize }}</mat-cell>\n    </ng-container>\n    <!-- Created Column mat-sort-header -->\n    <!-- <ng-container matColumnDef=\"created\">\n        <mat-header-cell *matHeaderCellDef fxHide fxShow.gt-md>Created</mat-header-cell>\n        <mat-cell *matCellDef=\"let row\" fxHide fxShow.gt-md>{{row.created?.date | date}}</mat-cell>\n    </ng-container> -->\n\n    <!-- Modified Column mat-sort-header -->\n    <ng-container matColumnDef=\"modified\">\n        <mat-header-cell *matHeaderCellDef fxHide fxShow.gt-md>Modified</mat-header-cell>\n        <mat-cell *matCellDef=\"let row\" fxHide fxShow.gt-md>{{row.change?.date | date}}</mat-cell>\n    </ng-container>\n\n    <!-- Detail Button Column -->\n    <ng-container matColumnDef=\"detail-button\">\n        <mat-header-cell *matHeaderCellDef fxFlex=\"48px\" fxHide.gt-md></mat-header-cell>\n        <mat-cell *matCellDef=\"let row\" fxFlex=\"48px\" fxHide.gt-md>\n            <button mat-icon-button class=\"sidebar-toggle\" fxHide.gt-md\n                    (click)=\"onAction( $event, 'info', row);\">\n                <mat-icon class=\"secondary-text\">info</mat-icon>\n            </button>\n        </mat-cell>\n    </ng-container>\n\n    <mat-header-row *matHeaderRowDef=\"displayedColumns\"></mat-header-row>\n    <mat-row *matRowDef=\"let row; columns: displayedColumns;\"\n             (click)=\"onAction($event,'select', row)\"\n             [ngClass]=\"{'selected' : row == selected}\" matRipple>\n        <!--[@animate]=\"{value:'*',params:{y:'100%'}}\"-->\n    </mat-row>\n    \n</mat-table>",
                encapsulation: ViewEncapsulation.None,
                styles: ["file-list{width:100%}file-list .mat-table{background:0 0;box-shadow:none}file-list .mat-table .mat-row{position:relative;cursor:pointer;min-height:64px}"]
            }] }
];
/** @nocollapse */
FileTableComponent.ctorParameters = () => [];
FileTableComponent.propDecorators = {
    displayedColumns: [{ type: Input }],
    dataSource: [{ type: Input }],
    selected: [{ type: Input }],
    action: [{ type: Output }],
    sort: [{ type: ViewChild, args: [MatSort, { static: true },] }]
};
if (false) {
    /** @type {?} */
    FileTableComponent.prototype.displayedColumns;
    /** @type {?} */
    FileTableComponent.prototype.dataSource;
    /** @type {?} */
    FileTableComponent.prototype.selected;
    /** @type {?} */
    FileTableComponent.prototype.action;
    /** @type {?} */
    FileTableComponent.prototype.sort;
}

/**
 * @fileoverview added by tsickle
 * Generated from: file/file-info/file-info.component.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/** @type {?} */
const TAG$1 = 'FileInfoComponent';
class FileInfoComponent {
    constructor() {
        this.directLink = "";
        this.groups = [];
        this.action = new EventEmitter();
    }
    /**
     * @return {?}
     */
    ngOnInit() {
    }
    /**
     * @param {?} group
     * @param {?} eve
     * @return {?}
     */
    toggleWriteGroups(group, eve) {
        if (eve.checked) {
            this.value.accessRights.writeGroups.push(group);
        }
        else {
            /** @type {?} */
            let groups = this.value.accessRights.writeGroups;
            /** @type {?} */
            let index = groups.indexOf(group);
            groups.splice(index, 1);
        }
    }
    /**
     * @param {?} group
     * @param {?} eve
     * @return {?}
     */
    toggleReadGroups(group, eve) {
        if (eve.checked) {
            this.value.accessRights.readGroups.push(group);
        }
        else {
            /** @type {?} */
            let groups = this.value.accessRights.readGroups;
            /** @type {?} */
            let index = groups.indexOf(group);
            groups.splice(index, 1);
        }
    }
    /**
     * @param {?} cmd
     * @param {?=} selected
     * @return {?}
     */
    onAction(cmd, selected = this.value) {
        if (isDevMode()) {
            console.debug(TAG$1, "onAction", cmd, selected);
        }
        this.fireAction((/** @type {?} */ ({ name: cmd, payload: selected })));
    }
    /**
     * @protected
     * @param {?} action
     * @return {?}
     */
    fireAction(action) {
        this.action.emit(action);
    }
}
FileInfoComponent.decorators = [
    { type: Component, args: [{
                selector: 'chain-docs-file-info',
                template: "<div class=\"content p-24\" fusePerfectScrollbar>\n\n    <div class=\"file-details\">\n\n        <!-- <div class=\"preview file-icon\" fxLayout=\"row\" fxLayoutAlign=\"center center\">\n            <img src=\"assets/dms-panel-info.png\" alt=\"Panel Image\">\n        </div> -->\n\n\n        <div class=\"title\">{{value?.fileName}}</div>\n\n        <ul class=\"info-list\">\n            <li>\n                <span>Privat</span>\n                <div class=\"offline-switch\">\n\n                    <!-- <mat-slide-toggle [(ngModel)]=\"value.offline\" labelPosition=\"before\"></mat-slide-toggle> -->\n                </div>\n            </li>\n            <li>\n                <span>Gr\u00F6\u00DFe</span>\n                <i>{{value?.fileSize  == undefined ? '-': value.fileSize }}</i>\n            </li>\n            <li>\n                <span>Erstellt</span>\n                <i>{{value?.created?.date | date}}</i>\n            </li>\n            <li>\n                <span>Ge\u00E4ndert</span>\n                <i>{{value?.change?.date | date}}</i>\n            </li>\n        </ul>\n\n        <ul class=\"info-list\">\n            <li>\n                <span>Owner</span>\n                <i><img src=\"https://via.placeholder.com/40x40\" alt=\"owner Image\">{{value?.created?.user}}</i>\n            </li>\n            <li *ngIf=\"value?.writeAccess\">\n                <span>Access right</span>\n                <i class=\"pointer\"><span></span>\n                    <mat-icon [matMenuTriggerFor]=\"accessRightsMenu\" #accessRightsMenu=\"matMenuTrigger\" class=\"s-16\">\n                        accessibility</mat-icon>\n                </i>\n\n                <mat-menu #accessRightsMenu=\"matMenu\" [overlapTrigger]=\"false\">\n                    <div class=\"header\" fxLayout=\"row\" fxLayoutAlign=\"space-between\">\n                        <div (click)=\"$event.stopPropagation()\" class=\"px-16 py-8\" fxFlex fxLayout=\"column\"\n                            fxLayoutAlign=\"start end\">\n\n                            <div fxFlex=\"0 1 auto\" fxLayout=\"row\" fxLayoutAlign=\"space-between center\">\n                                <button (click)=\"onAction('edit')\" class=\"\" mat-button>\n                                    <mat-icon class=\"s-16\">save</mat-icon>\n                                    Save\n                                </button>\n\n                            </div>\n\n                        </div>\n                    </div>\n                    <div fxFlex fxLayout=\"column\" class=\"access-rights-menu\" (click)=\"$event.stopPropagation()\">\n\n                        <table>\n                            <thead>\n                                <tr>\n                                    <th>Group</th>\n                                    <th>Read</th>\n                                    <th>Write</th>\n\n                                </tr>\n                            </thead>\n                            <tbody>\n                                <ng-container *ngFor=\"let group of groups\">\n                                    <tr *ngIf=\"group.name !='ADMINS' && group.name !='USER_MANAGERS'\">\n                                        <td>\n                                            <p class=\"group-name\">{{ group.name }}</p>\n                                        </td>\n                                        <td>\n                                            <mat-checkbox #cb class=\"member\"\n                                                (change)=\"toggleReadGroups(group.name,$event)\"\n                                                [checked]=\"value.accessRights.readGroups?.includes(group.name)\">\n                                            </mat-checkbox>\n                                        </td>\n                                        <td>\n                                            <mat-checkbox #cb class=\"member\"\n                                                (change)=\"toggleWriteGroups(group.name,$event)\"\n                                                [checked]=\"value.accessRights.writeGroups?.includes(group.name)\">\n                                            </mat-checkbox>\n\n                                        </td>\n                                    </tr>\n                                </ng-container>\n                            </tbody>\n                        </table>\n                    </div>\n                </mat-menu>\n            </li>\n        </ul>\n        <span (click)=\"onAction('download')\" *ngIf=\"value && value?.type=='FILE'\" class=\"download-btn pointer\">\n            <mat-icon class=\"s-16\">cloud_download</mat-icon> Download\n        </span>\n        <br><br>\n        <span  *ngIf=\"directLink !=''\" class=\"download-btn pointer\">\n            <mat-icon class=\"s-16\">link</mat-icon>{{directLink}}\n        </span>\n        <br><br>\n        <span *ngIf=\"value?.canDelete && value?.writeAccess\" (click)=\"onAction('delete')\" class=\"download-btn pointer\">\n            <mat-icon class=\"s-16\">delete</mat-icon> Delete\n        </span>\n        <span *ngIf=\"!value?.canDelete && value?.writeAccess\"  class=\"download-btn not-allowed\">\n            <mat-icon class=\"s-16\">delete</mat-icon> Delete\n        </span>\n    </div>\n\n</div>",
                styles: [":host{display:-webkit-box;display:flex;-webkit-box-orient:vertical;-webkit-box-direction:normal;flex-direction:column;-webkit-box-flex:1;flex:1 1 auto;height:100%}:host>.header{-webkit-box-flex:0;flex:0 1 auto;height:160px;min-height:160px;max-height:160px}:host>.content{-webkit-box-flex:1;flex:1}:host>.content .file-details .offline-switch{padding-bottom:16px;font-weight:600}:host>.content .file-details .title{padding:16px 0;color:#4aba8a;font-size:22px;text-align:right}:host>.content .file-details table{width:100%;text-align:left}:host>.content .file-details table tr td,:host>.content .file-details table tr th{padding:2px}:host>.content .file-details table tr th{color:#4aba8a}:host>.content .file-details table tr.type{text-transform:capitalize}:host>.content .file-details table tr.owner{text-transform:capitalize}.mat-slide-toggle-label{flex-wrap:wrap}.mat-slide-toggle-content{color:#4aba8a;-webkit-box-flex:0;flex:0 0 100%;max-width:100%;margin-bottom:7px;font-weight:700}ul.info-list{display:-webkit-box;display:flex;padding-left:0;list-style:none;flex-wrap:wrap;width:100%}ul.info-list>li{-webkit-box-flex:0;flex:0 0 auto;font-size:14px;padding:2px 4px;text-align:right;-webkit-box-flex:1;flex-grow:1}ul.info-list>li>span{font-weight:600;color:#4aba8a;display:block}ul.info-list>li i{height:initial!important;width:initial!important;line-height:initial!important;display:block;font-size:inherit!important;font-family:Muli!important;margin-top:3px;color:#000!important}ul.info-list>li img{border-radius:50%;width:30px;margin-right:5px;display:inline-block;vertical-align:middle}ul.info-list>li .mat-icon{margin-left:10px}ul.info-list+ul.info-list>li,ul.info-list>li:first-child{text-align:initial}span.download-btn{font-size:14px;color:#000}span.download-btn .mat-icon,ul.info-list>li .mat-icon{color:#4aba8a;vertical-align:middle;font-size:28px!important;width:auto!important}ul.info-list>li svg{fill:#4aba8a}.pointer{cursor:pointer!important}.access-rights-menu{max-height:325px}.access-rights-menu .mat-checkbox-label,.access-rights-menu .mat-checkbox-layout{display:-webkit-box;display:flex;-webkit-box-flex:1;flex:1}.access-rights-menu table thead tr th{color:#4aba8a;padding:5px;text-transform:capitalize}.access-rights-menu table tbody tr td p.group-name{margin:0;width:170px;white-space:nowrap;text-overflow:ellipsis;overflow:hidden}.access-rights-menu table tbody tr:nth-child(2n){background-color:#f7f7f7}.access-rights-menu table tbody tr td{padding:5px;border:0!important}.access-rights-menu table{border-collapse:collapse}.access-rights-menu table tbody tr td:first-child{width:170px!important}.access-rights-menu table tbody tr td:not(:first-child){width:20px}.not-allowed{cursor:not-allowed!important;opacity:.4!important}"]
            }] }
];
/** @nocollapse */
FileInfoComponent.ctorParameters = () => [];
FileInfoComponent.propDecorators = {
    value: [{ type: Input }],
    directLink: [{ type: Input }],
    isPrivate: [{ type: Input }],
    groups: [{ type: Input }],
    action: [{ type: Output }]
};
if (false) {
    /** @type {?} */
    FileInfoComponent.prototype.value;
    /** @type {?} */
    FileInfoComponent.prototype.directLink;
    /** @type {?} */
    FileInfoComponent.prototype.isPrivate;
    /** @type {?} */
    FileInfoComponent.prototype.groups;
    /** @type {?} */
    FileInfoComponent.prototype.action;
}

/**
 * @fileoverview added by tsickle
 * Generated from: file-comp.module.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
//import {MatSortModule} from "@angular/material/sort";
class FileCompModule {
}
FileCompModule.decorators = [
    { type: NgModule, args: [{
                declarations: [
                    FileTableComponent,
                    FileInfoComponent
                ],
                imports: [
                    // BrowserModule,
                    // BrowserAnimationsModule,
                    CommonModule,
                    //BrowserAnimationsModule,
                    MatButtonModule,
                    MatIconModule,
                    MatRippleModule,
                    MatSlideToggleModule,
                    MatTableModule,
                    MatSortModule,
                    MatTooltipModule,
                    FlexLayoutModule,
                    MatMenuModule,
                    MatCheckboxModule
                ],
                exports: [
                    FileTableComponent,
                    FileInfoComponent
                ],
                schemas: [CUSTOM_ELEMENTS_SCHEMA]
            },] }
];

/**
 * @fileoverview added by tsickle
 * Generated from: public-api.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * Generated from: yukawa-chain-docs-angular-comp.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

export { FileCompModule, FileInfoComponent, FileInfoQueryStore, FileTableComponent };
//# sourceMappingURL=yukawa-chain-docs-angular-comp.js.map
